@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include item.R
 #' @include unitizer.R
 #' @include class_unions.R
@@ -649,8 +665,9 @@ setMethod("+", c("unitizerBrowse", "unitizerBrowseSection"), valueClass="unitize
 
     mapping.new <- new("unitizerBrowseMapping",
       # This id tracks the order of tests as we intend to review them
+      # is it possible for sum(item.count) to be zero?
       item.id=(max.item + 1L):(max.item + sum(item.count)),
-      item.id.rel=unlist(lapply(item.count, function(x) seq(len=x))),
+      item.id.rel=unlist(lapply(item.count, function(x) seq(length.out=x))),
       item.id.orig=vapply(sec.item.list, slot, 1L, "id"),
       item.ref=vapply(sec.item.list, slot, FALSE, "reference"),
       sec.id=rep(length(e1), sum(item.count)),
@@ -977,7 +994,7 @@ setClass("unitizerBrowseSubSectionNew", contains="unitizerBrowseSubSection",
     help=paste0(
       "A new test will be used as the reference value for future tests, so ",
       "make sure you review the value carefully before you add it to the ",
-      "store by selecting 'Y' at the prompt."
+      "store by selecting 'Y' at the prompt.%s%s"
     ),
     actions=c(Y="A", N="C"), show.out=TRUE
 ) )
@@ -1003,7 +1020,7 @@ setClass("unitizerBrowseSubSectionCorrupted",
       "because the comparison function itself caused an error.  You can ",
       "change the unitizer function with `unitizer_sect`.  You can also ",
       "manually compare `.NEW` and `.REF` and decide whether to replace the ",
-      "old value with the new one by selecting 'Y' at the prompt."
+      "old value with the new one by selecting 'Y' at the prompt.%s%s"
     ),
     actions=c(Y="A", N="B")
 ) )
@@ -1021,7 +1038,7 @@ setClass("unitizerBrowseSubSectionRemoved", contains="unitizerBrowseSubSection",
     ),
     help=paste0(
       "A previously stored test no longer exists in the test file; you can ",
-      "remove the stored value by selecting 'Y' at the prompt."
+      "remove the stored value by selecting 'Y' at the prompt.%s%s"
     ),
     actions=c(Y="C", N="B")
 ) )
